Learn R Programming

messina (version 1.8.2)

messinaTopResults: Display a summary of the top results from a Messina analysis

Description

Sorts the summary results of a Messina analysis in decreasing order of classifier margin, and displays the top n. The full sorted data.frame is invisibly returned. If n == 0, displays nothing, but still invisibly returns the full data.frame.

Usage

messinaTopResults(result, n = 10)

Arguments

result
the result returned by a call to messina, messinaDE, or messinaSurv.
n
the maximum number of top hits to display (default 10). If zero, no results are displayed, but the full data.frame of results is still returned.

Value

  • (invisible) the full table of hits, as a data.frame sorted in order of decreasing margin.

Details

The displayed data.frame has the following columns. Users are encouraged to consult the vignette for a tutorial on how to interpret these results for classification and gene expression tasks. [object Object],[object Object],[object Object],[object Object],[object Object],[object Object]

See Also

messina

messinaDE

messinaSurv

MessinaClassResult-class

Examples

Run this code
## Load some example data
library(antiProfilesData)
data(apColonData)

x = exprs(apColonData)
y = pData(apColonData)$SubType

## Subset the data to only tumour and normal samples
sel = y %in% c("normal", "tumor")
x = x[,sel]
y = y[sel]

## Find differentially-expressed probesets.  Allow a sample misattribution rate of
## at most 20\%.
fit = messina(x, y == "tumor", min_sens = 0.95, min_spec = 0.85)

## Print the 20 probesets with the strongest evidence for differential expression
## between tumour and normal.  Save the full table of summary results for later use.
summary_table = messinaTopResults(fit, 20)

## Access the top five probesets in the table
summary_table[1:5,]

## Examine the summary results for particular probes
summary_table[c("204719_at", "207502_at"),]

Run the code above in your browser using DataLab