Learn R Programming

messina (version 1.8.2)

show,MessinaResult-method: Generic show methods for Messina objects.

Description

Generic show methods for Messina objects.

Usage

## S3 method for class 'MessinaResult':
show(object)

## S3 method for class 'MessinaParameters': show(object)

## S3 method for class 'MessinaFits': show(object)

Arguments

object
Any R object

Details

For details of the objects and their generation, see the relevant class documentation, and entries for the main functions messina, messinaDE, and messinaSurv,

See Also

MessinaResult-class

MessinaParameters-class

MessinaFits-class

messina

messinaDE

messinaSurv